searchData={"items":[{"type":"module","title":"JediHelpers","doc":"Documentation for `JediHelpers`.","ref":"JediHelpers.html"},{"type":"function","title":"JediHelpers.atom_to_readable_string/1","doc":"Converts an atom into a human-readable string by title-casing its segments.\n\nUseful for displaying labels or headings derived from atoms.","ref":"JediHelpers.html#atom_to_readable_string/1"},{"type":"function","title":"Examples - JediHelpers.atom_to_readable_string/1","doc":"iex> JediHelpers.atom_to_readable_string(:user_profile)\n    \"User Profile\"\n\n    iex> JediHelpers.atom_to_readable_string(:admin)\n    \"Admin\"","ref":"JediHelpers.html#atom_to_readable_string/1-examples"},{"type":"function","title":"JediHelpers.format_decimal/1","doc":"Formats a decimal or numeric input by:\n\n  - Converting it to a `Decimal`\n  - Rounding to 2 decimal places\n  - Converting to a string\n  - Adding thousands separators (e.g., `\"1,234.56\"`)\n\nReturns `nil` if the input is `nil`.","ref":"JediHelpers.html#format_decimal/1"},{"type":"function","title":"Examples - JediHelpers.format_decimal/1","doc":"iex> format_decimal(1234567.891)\n    \"1,234,567.89\"\n\n    iex> format_decimal(\"1000.1\")\n    \"1,000.10\"\n\n    iex> format_decimal(nil)\n    nil","ref":"JediHelpers.html#format_decimal/1-examples"},{"type":"function","title":"Requirements - JediHelpers.format_decimal/1","doc":"Requires the `:decimal` and `:number` libraries.","ref":"JediHelpers.html#format_decimal/1-requirements"},{"type":"function","title":"JediHelpers.format_money/3","doc":"Formats a given amount into a currency string using `Money`.","ref":"JediHelpers.html#format_money/3"},{"type":"function","title":"Parameters - JediHelpers.format_money/3","doc":"- `amount`: A number representing the amount to format. Supported types:\n    - `Money` struct (used directly)\n    - `Decimal` (e.g., from Ecto fields)\n    - `integer` (treated as the smallest unit, like cents)\n    - `float`\n    - `string` (parsed into a Money amount)\n  - `currency`: A string or atom representing the ISO 4217 currency code (e.g., `:php` for Philippine Peso).\n  - `opts` (optional): A keyword list of formatting options passed to `Money.to_string/2`.","ref":"JediHelpers.html#format_money/3-parameters"},{"type":"function","title":"Returns - JediHelpers.format_money/3","doc":"- A formatted currency string on success.\n  - Raises a `RuntimeError` on formatting failure.\n  - Raises an `ArgumentError` for unsupported amount types.\n  - Returns `nil` if the `amount` is `nil`.","ref":"JediHelpers.html#format_money/3-returns"},{"type":"function","title":"Examples - JediHelpers.format_money/3","doc":"iex> format_money(1000, :php)\n    \"₱1,000.00\"\n\n    iex> format_money(nil, :php)\n    nil\n\n    iex> format_money(Decimal.new(\"1234.56\"), :usd)\n    \"$1,234.56\"\n\n    iex> format_money(1234.56, :php, symbol: false)\n    \"1,234.56 PHP\"","ref":"JediHelpers.html#format_money/3-examples"},{"type":"function","title":"Formatting Options - JediHelpers.format_money/3","doc":"The `opts` are forwarded to `Money.to_string/2`.  \nRefer to the [ex_money Money.to_string/2 documentation](https://hexdocs.pm/ex_money/Money.html#to_string/2) for the full list of supported options.","ref":"JediHelpers.html#format_money/3-formatting-options"},{"type":"function","title":"JediHelpers.format_name/1","doc":"Formats a user's full name as `\"First Last\"`.\n\nReturns `nil` if the input is `nil`.","ref":"JediHelpers.html#format_name/1"},{"type":"function","title":"Examples - JediHelpers.format_name/1","doc":"iex> format_name(%{first_name: \"Luke\", last_name: \"Skywalker\"})\n    \"Luke Skywalker\"","ref":"JediHelpers.html#format_name/1-examples"},{"type":"function","title":"JediHelpers.format_name/2","doc":"Formats a user's name as `\"Last, First\"` if `:last_first` style is passed.","ref":"JediHelpers.html#format_name/2"},{"type":"function","title":"Examples - JediHelpers.format_name/2","doc":"iex> format_name(%{first_name: \"Luke\", last_name: \"Skywalker\"}, :last_first)\n    \"Skywalker, Luke\"","ref":"JediHelpers.html#format_name/2-examples"},{"type":"function","title":"JediHelpers.format_name_with_email/1","doc":"Formats a user's full name with email as `\"First Last - email@example.com\"`.","ref":"JediHelpers.html#format_name_with_email/1"},{"type":"function","title":"Examples - JediHelpers.format_name_with_email/1","doc":"iex> format_name_with_email(%{first_name: \"Leia\", last_name: \"Organa\", email: \"leia@alderaan.com\"})\n    \"Leia Organa - leia@alderaan.com\"","ref":"JediHelpers.html#format_name_with_email/1-examples"},{"type":"function","title":"JediHelpers.number_to_words/1","doc":"","ref":"JediHelpers.html#number_to_words/1"},{"type":"function","title":"JediHelpers.resource_type/1","doc":"Returns the underscored (snake_case) name of a struct's module as a string.\n\nUseful for generating type identifiers from structs, especially in APIs or dynamic logic.","ref":"JediHelpers.html#resource_type/1"},{"type":"function","title":"Example - JediHelpers.resource_type/1","doc":"iex> resource_type(%JediHelpers.BlogPost{})\n    \"blog_post\"","ref":"JediHelpers.html#resource_type/1-example"},{"type":"function","title":"Parameters: - JediHelpers.resource_type/1","doc":"- `resource` (`struct`): Any Elixir struct.","ref":"JediHelpers.html#resource_type/1-parameters"},{"type":"function","title":"Returns: - JediHelpers.resource_type/1","doc":"- `String.t()`: The snake_case name of the struct's module (last segment only).","ref":"JediHelpers.html#resource_type/1-returns"},{"type":"function","title":"JediHelpers.trim_description/2","doc":"Trims the `:description` field of the given resource to a maximum length.","ref":"JediHelpers.html#trim_description/2"},{"type":"function","title":"Parameters - JediHelpers.trim_description/2","doc":"- resource: A map that must contain a non-nil, binary `:description` key.\n  - max_length: The maximum length of the trimmed description (default is 50).","ref":"JediHelpers.html#trim_description/2-parameters"},{"type":"function","title":"Examples - JediHelpers.trim_description/2","doc":"iex> trim_description(%{description: \"This is a very long description that needs trimming\"}, 10)\n    \"This is a \"\n\n    iex> trim_description(%{description: \"Short\"}, 10)\n    \"Short\"","ref":"JediHelpers.html#trim_description/2-examples"},{"type":"function","title":"Raises - JediHelpers.trim_description/2","doc":"Raises `ArgumentError` if the `resource` does not contain a non-nil, binary `:description` field.","ref":"JediHelpers.html#trim_description/2-raises"},{"type":"function","title":"JediHelpers.uri_parse_path/1","doc":"Extracts the path segment from a URI string.\n\nUseful for isolating the path portion of a full URL (e.g. `/users/123`).","ref":"JediHelpers.html#uri_parse_path/1"},{"type":"function","title":"Example - JediHelpers.uri_parse_path/1","doc":"iex> uri_parse_path(\"https://example.com/users/123?ref=home\")\n    \"/users/123\"","ref":"JediHelpers.html#uri_parse_path/1-example"},{"type":"function","title":"Parameters: - JediHelpers.uri_parse_path/1","doc":"- `uri` (`String.t()`): A URI string.","ref":"JediHelpers.html#uri_parse_path/1-parameters"},{"type":"function","title":"Returns: - JediHelpers.uri_parse_path/1","doc":"- `String.t()` or `nil`: The path component of the URI, or `nil` if absent.","ref":"JediHelpers.html#uri_parse_path/1-returns"},{"type":"module","title":"JediHelpers.ChangesetHelpers","doc":"Provides helper functions for trimming whitespace and validating string fields\nin Ecto changesets. Particularly useful for ensuring uniqueness and formatting\nof string inputs before applying database constraints.","ref":"JediHelpers.ChangesetHelpers.html"},{"type":"function","title":"JediHelpers.ChangesetHelpers.trim_whitespace/3","doc":"Trims leading and trailing whitespaces from the specified fields in the changeset.\nThis ensures consistency and helps maintain uniqueness, especially for `citext` fields.","ref":"JediHelpers.ChangesetHelpers.html#trim_whitespace/3"},{"type":"function","title":"Options - JediHelpers.ChangesetHelpers.trim_whitespace/3","doc":"- `:max` (`integer`): Maximum allowed length after trimming. If exceeded, a validation error is added. Default is 255.\n- `:enforce_unique` (`boolean`): When set to `true`, adds a `unique_constraint/3` to the field. Default is `false`.","ref":"JediHelpers.ChangesetHelpers.html#trim_whitespace/3-options"},{"type":"function","title":"Example - JediHelpers.ChangesetHelpers.trim_whitespace/3","doc":"changeset\n    |> trim_whitespace(:username, max: 50, enforce_unique: true)","ref":"JediHelpers.ChangesetHelpers.html#trim_whitespace/3-example"},{"type":"function","title":"Parameters - JediHelpers.ChangesetHelpers.trim_whitespace/3","doc":"- `changeset` (`Ecto.Changeset.t()`): The changeset containing the field(s) to be processed.\n- `field` (`atom()` or `[atom()]`): The field(s) to trim.\n- `opts` (`keyword()`): Options for trimming and validation.","ref":"JediHelpers.ChangesetHelpers.html#trim_whitespace/3-parameters"},{"type":"function","title":"Returns - JediHelpers.ChangesetHelpers.trim_whitespace/3","doc":"- An updated `Ecto.Changeset.t()` with trimmed values and optional validations.","ref":"JediHelpers.ChangesetHelpers.html#trim_whitespace/3-returns"},{"type":"module","title":"JediHelpers.DateUtils","doc":"","ref":"JediHelpers.DateUtils.html"},{"type":"function","title":"JediHelpers.DateUtils.to_date/1","doc":"Parses a variety of date formats into a `Date` struct.","ref":"JediHelpers.DateUtils.html#to_date/1"},{"type":"function","title":"Supported inputs - JediHelpers.DateUtils.to_date/1","doc":"* `\"\"` or `\"0\"` – returns `nil`\n* A `Date` struct – returns the date itself\n* Excel serial date string (e.g. `\"40135\"`) – returns the corresponding `Date`\n* ISO-ish strings (e.g. `\"2023-1-5\"`, `\"2023-01-05\"`) – returns the parsed `Date`\n* Strings with leading/trailing whitespace are trimmed\n* Invalid or malformed strings return `nil`","ref":"JediHelpers.DateUtils.html#to_date/1-supported-inputs"},{"type":"function","title":"Examples - JediHelpers.DateUtils.to_date/1","doc":"iex> to_date(\"40135\")\n~D[2009-11-18]\n\niex> to_date(\"2024-1-9\")\n~D[2024-01-09]\n\niex> to_date(\"\")\nnil\n\niex> to_date(%Date{year: 2020, month: 5, day: 10})\n~D[2020-05-10]\n\niex> to_date(\"not a date\")\nnil","ref":"JediHelpers.DateUtils.html#to_date/1-examples"},{"type":"module","title":"JediHelpers.FormHelpers","doc":"Helper functions for form inputs and options.","ref":"JediHelpers.FormHelpers.html"},{"type":"function","title":"JediHelpers.FormHelpers.options_for/2","doc":"Generates `{label, id}` tuples for a list of maps or structs to be used in dropdowns.","ref":"JediHelpers.FormHelpers.html#options_for/2"},{"type":"function","title":"Examples - JediHelpers.FormHelpers.options_for/2","doc":"iex> users = [%{id: 1, name: \"Alice\"}, %{id: 2, name: \"Bob\"}]\n    iex> JediHelpers.FormHelpers.options_for(users, :name)\n    [{\"Alice\", 1}, {\"Bob\", 2}]\n\nRaises if an element is not a map or struct, or if the arguments are invalid.","ref":"JediHelpers.FormHelpers.html#options_for/2-examples"},{"type":"extras","title":"JediHelpers","doc":"# JediHelpers\n\nA collection of general-purpose helpers for Elixir projects, designed to make your codebase cleaner and more reusable. Includes utilities for working with changesets and common functional patterns.","ref":"readme.html"},{"type":"extras","title":"Features - JediHelpers","doc":"- `JediHelpers.ChangesetHelpers.trim_whitespace/2` – trims leading and trailing whitespace from string fields in Ecto changesets.\n- Other helper functions coming soon.","ref":"readme.html#features"},{"type":"extras","title":"Installation - JediHelpers","doc":"Add `:jedi_helpers` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:jedi_helpers, \"~> 0.2.2\"}\n  ]\nend\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\n## [0.2.2] - 2025-05-15","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- trim_whitespace/3 – Trims spaces in changeset fields and adds unique_constraint + max length validation.\n- number_to_words/1 – Converts a number into its word form.\n- trim_description/2 – Truncates a string with ellipsis.\n\n## [0.2.1] - 2025-05-15","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Enhanced `format_money/3` to support `Decimal` and properly parse binary strings representing decimals.\n- Added error handling to `format_money/3` for invalid or malformed binary string inputs, raising `ArgumentError`.\n- Added unit tests covering valid and invalid binary string inputs for `format_money/3`.\n\n## [0.2.0] - 2025-05-14","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- `to_date/3` to parse dates with an optional fallback or custom parsing logic.\n\n## [0.1.2] - 2025-05-11","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- `format_money/3` to format monetary amounts using `Money.to_string/2` with optional formatting options.\n\n## [0.1.1] - 2025-05-09","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- `format_decimal/1` to format decimals with commas and 2 decimal places.\n- `format_name/1` and `format_name/2` for flexible user name formatting.\n- `format_name_with_email/1` for full name + email formatting.\n\n## [0.1.0] - 2025-05-06","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release with Changeset Helpers,  FormHelpers, and other utility functions.","ref":"changelog.html#added"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}